@@ -9,10 +9,12 @@
 from operator import itemgetter
 from functools import partial
 from . import filters
+from .version import VERSION
 import jinja2
 import plistlib
 import os
 import pytz
+from collections import defaultdict
 
 SUBKEYS = {'Location': ['Locality', 'Country', 'Place Name',
                  'Administrative Area', 'Longitude', 'Latitude'],
@@ -128,6 +130,18 @@ class Entry(object):
 
         return ", ".join(names)
 
+    def weather(self, temperature_type):
+        if not 'Weather' in self:
+            return "" # fail silently
+
+        if temperature_type.lower() == 'celsius' or temperature_type.lower() == 'c':
+            temperature = self.data['Celsius']
+        else:
+            temperature = self.data['Fahrenheit']
+
+        weather = "{0}&deg; {1}".format(temperature, self.data['Description'])
+        return weather
+
     def __getitem__(self, key):
         return self.data[key]
 
@@ -243,7 +257,8 @@ def _filter_by_after_date(journal, date):
     return [item for item in journal if item['Creation Date'] > date]
 
 def dayone_export(dayone_folder, template=None, reverse=False, tags=None,
-    after=None, format=None, template_dir=None, autobold=False, nl2br=False):
+    after=None, format=None, template_dir=None, autobold=False, nl2br=False,
+    filename_template=""):
     """Render a template using entries from a Day One journal.
 
     :param dayone_folder: Name of Day One folder; generally ends in ``.dayone``.
@@ -275,19 +290,35 @@ def dayone_export(dayone_folder, template=None, reverse=False, tags=None,
     :type autobold: bool
     :param nl2br:  Specifies that new lines should be translated in to <br>s
     :type nl2br: bool
-    :returns: Filled in template as string.
+    :type filename_template: string
+    :param filename_template: An eventual filename, which can include strftime formatting codes.
+                Each time the result of formatting an entry's timestamp with this changes,
+                a new result will be returned.
+    :returns: Iterator yielding (filename, filled_in_template) as strings on each iteration.
     """
 
     # figure out which template to use
     loader, template = _determine_inheritance(template, template_dir, format)
-    env = jinja2.Environment(loader=loader, trim_blocks=True)
+
+    # custom latex template syntax
+    custom_syntax = {}
+    if os.path.splitext(template)[1] == ".tex":
+        custom_syntax = {'block_start_string': r'\CMD{',
+                         'block_end_string': '}',
+                         'variable_start_string': r'\VAR{',
+                         'variable_end_string': '}',
+                         }
+    # define jinja environment
+    env = jinja2.Environment(loader=loader, trim_blocks=True, **custom_syntax)
 
     # filters
     env.filters['markdown'] = filters.markdown_filter(autobold=autobold)
     env.filters['format'] = filters.format
+    env.filters['escape_tex'] = filters.escape_tex
     env.filters['imgbase64'] = partial(filters.imgbase64,
       dayone_folder=dayone_folder)
 
+
     # load template
     template = env.get_template(template)
 
@@ -309,7 +340,20 @@ def dayone_export(dayone_folder, template=None, reverse=False, tags=None,
     if reverse:
         j.reverse()
 
-    # may throw an exception if the template is malformed
-    # the traceback is helpful, so i'm letting it through
+
+    # Split into groups, possibly of length one
+    # Generate a new output for each time the 'filename_template' changes.
+    # Yield the resulting filename_template plus the output.
+    # If the filename_template is an empty string (the default), we'll get
+    # an empty grouper plus the rendering of the full list of entries.
+    # This may throw an exception if the template is malformed.
+    # The traceback is helpful, so I'm letting it through
     # it might be nice to clean up the error message, someday
-    return template.render(journal=j)
+
+    output_groups = defaultdict(list)
+    for e in j:
+        output_groups[e['Date'].strftime(filename_template)].append(e)
+
+    for k in output_groups:
+        yield k, template.render(journal=output_groups[k])
+
